@@ -1,3 +1,14 @@
+
+*     2018-09-26 NJM edits: 
+*          changed REALPART to REAL
+*          changed IMAGPART to AIMAG
+*          changed DCONJG to CONJG
+*          ...throughout
+*          (I guess these are gfortran GNU extensions; cause 
+*           problems on flang compiler, according to
+*           email from Brian Ripley)
+*
+
 *     This is a lightweight substitute to the external LAPACK routines 
 *     used by EXPOKIT. It is supplied to ensure that EXPOKIT is 
 *     self-contained and can still run if LAPACK is not yet installed
@@ -129,12 +140,12 @@ c     dreal(zdumr) = zdumr
 c     dimag(zdumi) = (0.0d0,-1.0d0)*zdumi
 
 c     Statement function:
-c      cabs1(zdum) = dabs(REAL(zdum)) + dabs(AIMAG(zdum))
+c      cabs1(zdum) = dabs(REALPART(zdum)) + dabs(IMAGPART(zdum))
 c     FIX:
 c      double precision cabs1
 c      double precision pta, ptb
-c      pta = REAL(zdum)
-c      ptb = AIMAG(zdum)
+c      pta = REALPART(zdum)
+c      ptb = IMAGPART(zdum)
 c      ((dabs(pta)+dabs(ptb))
 
 
@@ -308,7 +319,7 @@ c        first solve  ctrans(u)*y = b
 c
          do 60 k = 1, n
             t = zdotc(k-1,a(1,k),1,b(1),1)
-            b(k) = (b(k) - t)/dconjg(a(k,k))
+            b(k) = (b(k) - t)/conjg(a(k,k))
    60    continue
 c
 c        now solve ctrans(l)*x = y
@@ -383,7 +394,7 @@ c
 c     subroutines and functions
 c
 c     blas zaxpy,zswap,izamax
-c     fortran dabs,dmax1,dcmplx,dconjg,dsqrt
+c     fortran dabs,dmax1,dcmplx,conjg,dsqrt
 c
 c     internal variables
 c
@@ -402,7 +413,7 @@ c      dreal(zdumr) = zdumr
 c      dimag(zdumi) = (0.0d0,-1.0d0)*zdumi
 
 c FIX:
-c      cabs1(zdum) = dabs(REAL(zdum)) + dabs(AIMAG(zdum))
+c      cabs1(zdum) = dabs(REALPART(zdum)) + dabs(IMAGPART(zdum))
 c
 c     initialize
 c
@@ -537,8 +548,8 @@ c
                call zswap(imax,a(1,imax),1,a(1,k),1)
                do 110 jj = imax, k
                   j = k + imax - jj
-                  t = dconjg(a(j,k))
-                  a(j,k) = dconjg(a(imax,j))
+                  t = conjg(a(j,k))
+                  a(j,k) = conjg(a(imax,j))
                   a(imax,j) = t
   110          continue
   120       continue
@@ -548,7 +559,7 @@ c
             do 130 jj = 1, km1
                j = k - jj
                mulk = -a(j,k)/a(k,k)
-               t = dconjg(mulk)
+               t = conjg(mulk)
                call zaxpy(j,t,a(1,k),1,a(1,j),1)
                a(j,j) = dcmplx(REAL(a(j,j)),0.0d0)
                a(j,k) = mulk
@@ -570,8 +581,8 @@ c
                call zswap(imax,a(1,imax),1,a(1,k-1),1)
                do 150 jj = imax, km1
                   j = km1 + imax - jj
-                  t = dconjg(a(j,k-1))
-                  a(j,k-1) = dconjg(a(imax,j))
+                  t = conjg(a(j,k-1))
+                  a(j,k-1) = conjg(a(imax,j))
                   a(imax,j) = t
   150          continue
                t = a(k-1,k)
@@ -584,17 +595,17 @@ c
             km2 = k - 2
             if (km2 .eq. 0) go to 180
                ak = a(k,k)/a(k-1,k)
-               akm1 = a(k-1,k-1)/dconjg(a(k-1,k))
+               akm1 = a(k-1,k-1)/conjg(a(k-1,k))
                denom = 1.0d0 - ak*akm1
                do 170 jj = 1, km2
                   j = km1 - jj
                   bk = a(j,k)/a(k-1,k)
-                  bkm1 = a(j,k-1)/dconjg(a(k-1,k))
+                  bkm1 = a(j,k-1)/conjg(a(k-1,k))
                   mulk = (akm1*bk - bkm1)/denom
                   mulkm1 = (ak*bkm1 - bk)/denom
-                  t = dconjg(mulk)
+                  t = conjg(mulk)
                   call zaxpy(j,t,a(1,k),1,a(1,j),1)
-                  t = dconjg(mulkm1)
+                  t = conjg(mulkm1)
                   call zaxpy(j,t,a(1,k-1),1,a(1,j),1)
                   a(j,k) = mulk
                   a(j,k-1) = mulkm1
@@ -725,9 +736,9 @@ c
 c
 c           apply d inverse.
 c
-            ak = a(k,k)/dconjg(a(k-1,k))
+            ak = a(k,k)/conjg(a(k-1,k))
             akm1 = a(k-1,k-1)/a(k-1,k)
-            bk = b(k)/dconjg(a(k-1,k))
+            bk = b(k)/conjg(a(k-1,k))
             bkm1 = b(k-1)/a(k-1,k)
             denom = ak*akm1 - 1.0d0
             b(k) = (akm1*bk - bkm1)/denom
@@ -861,7 +872,7 @@ c      complex(kind=8) zdumr,zdumi
 
 c      dreal(zdumr) = zdumr
 c      dimag(zdumi) = (0.0d0,-1.0d0)*zdumi
-c      cabs1(zdum) = dabs(REAL(zdum)) + dabs(AIMAG(zdum))
+c      cabs1(zdum) = dabs(REALPART(zdum)) + dabs(IMAGPART(zdum))
 c
 c     initialize
 c
